==> peg-e_1.2.4.orig.tar.gz: peg-e-1.2.4/translations/pege_zh.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh">
<context>
    <name>Board</name>
    <message>
        <source>Success</source>
        <translation>恭喜你，你赢了！</translation>
    </message>
    <message>
        <source>Game Over</source>
        <translation>游戏结束</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>选择本游戏的语言</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>系统语言</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>提示</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>请重启本程序使语言设置生效</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Peg-E</source>
        <translation>Peg-E</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;游戏</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;新游戏</translation>
    </message>
    <message>
        <source>&amp;Restart Game</source>
        <translation>&amp;重新开始</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;本局游戏详情</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>退出程序</translation>
    </message>
    <message>
        <source>&amp;Move</source>
        <translation>&amp;移动</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;悔棋（撤销）</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>重做</translation>
    </message>
    <message>
        <source>&amp;Appearance</source>
        <translation>棋子颜色</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation>蓝</translation>
    </message>
    <message>
        <source>Charcoal</source>
        <translation>碳灰</translation>
    </message>
    <message>
        <source>Green</source>
        <translation>绿</translation>
    </message>
    <message>
        <source>Midnight</source>
        <translation>深蓝</translation>
    </message>
    <message>
        <source>Plum</source>
        <translation>紫红</translation>
    </message>
    <message>
        <source>Red</source>
        <translation>红</translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation>黄</translation>
    </message>
    <message>
        <source>Custom...</source>
        <translation>自定义...</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;设置</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>程序 &amp;语言...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;帮助</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;关于</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>关于 &amp;Qt</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>新建游戏</translation>
    </message>
    <message>
        <source>Original</source>
        <translation>原始</translation>
    </message>
    <message>
        <source>Branch</source>
        <translation>分支</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>线性</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>随机</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>算法：</translation>
    </message>
    <message>
        <source>Difficulty:</source>
        <translation>难度：</translation>
    </message>
    <message>
        <source>Seed:</source>
        <translation>排序：</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>问题</translation>
    </message>
    <message>
        <source>Do you want to restart?</source>
        <translation>你想要重新开始本局吗？</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>本局游戏详情</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;Algorithm:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Difficulty:&lt;/b&gt; %2&lt;br&gt;&lt;b&gt;Seed:&lt;/b&gt; %L3&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;算法：&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;难度：&lt;/b&gt; %2&lt;br&gt;&lt;b&gt;排序：&lt;/b&gt; %L3&lt;/p&gt;</translation>
    </message>
    <message>
        <source>About Peg-E</source>
        <translation>关于 Peg-E</translation>
    </message>
    <message>
        <source>Peg elimination game</source>
        <translation>一款孔明棋游戏</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>版权所有 &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>基于 &lt;a href=%1&gt;GPL 3&lt;/a&gt; 协议发布</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>使用 &lt;a href=%1&gt;Oxygen&lt;/a&gt; 风格图标</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>在 &lt;a href=%1&gt;LGPL 3&lt;/a&gt; 协议下授权用户使用</translation>
    </message>
</context>
</TS>

==> peg-e_1.3.2.orig.tar.gz: peg-e-1.3.2/translations/pege_zh.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh">
<context>
    <name>Board</name>
    <message>
        <source>Success</source>
        <translation>恭喜你，你赢了！</translation>
    </message>
    <message>
        <source>Game Over</source>
        <translation>游戏结束</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>选择本游戏的语言:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;系统语言&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>提示</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>请重启本程序使语言设置生效。</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Peg-E</source>
        <translation>Peg-E</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;游戏</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;新游戏</translation>
    </message>
    <message>
        <source>&amp;Restart Game</source>
        <translation>&amp;重新开始</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;本局游戏详情</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>退出程序</translation>
    </message>
    <message>
        <source>&amp;Move</source>
        <translation>&amp;移动</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;悔棋（撤销）</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>重做</translation>
    </message>
    <message>
        <source>&amp;Appearance</source>
        <translation>棋子颜色</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation>蓝</translation>
    </message>
    <message>
        <source>Charcoal</source>
        <translation>碳灰</translation>
    </message>
    <message>
        <source>Green</source>
        <translation>绿</translation>
    </message>
    <message>
        <source>Midnight</source>
        <translation>深蓝</translation>
    </message>
    <message>
        <source>Plum</source>
        <translation>紫红</translation>
    </message>
    <message>
        <source>Red</source>
        <translation>红</translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation>黄</translation>
    </message>
    <message>
        <source>Custom...</source>
        <translation>自定义...</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;设置</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>程序 &amp;语言...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;帮助</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;关于</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>关于 &amp;Qt</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>新建游戏</translation>
    </message>
    <message>
        <source>Original</source>
        <translation>原始</translation>
    </message>
    <message>
        <source>Branch</source>
        <translation>分支</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>线性</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>随机</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>算法：</translation>
    </message>
    <message>
        <source>Difficulty:</source>
        <translation>难度：</translation>
    </message>
    <message>
        <source>Seed:</source>
        <translation>种子：</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>问题</translation>
    </message>
    <message>
        <source>Do you want to restart?</source>
        <translation>你想要重新开始本局吗？</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>本局游戏详情</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;Algorithm:&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;Difficulty:&lt;/b&gt; %2&lt;br&gt;&lt;b&gt;Seed:&lt;/b&gt; %L3&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;算法：&lt;/b&gt; %1&lt;br&gt;&lt;b&gt;难度：&lt;/b&gt; %2&lt;br&gt;&lt;b&gt;排序：&lt;/b&gt; %L3&lt;/p&gt;</translation>
    </message>
    <message>
        <source>About Peg-E</source>
        <translation>关于 Peg-E</translation>
    </message>
    <message>
        <source>Peg elimination game</source>
        <translation>一款孔明棋游戏</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>版权所有 &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>基于 &lt;a href=%1&gt;GPL 3&lt;/a&gt; 协议发布</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>使用 &lt;a href=%1&gt;Oxygen&lt;/a&gt; 风格图标</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>在 &lt;a href=%1&gt;LGPL 3&lt;/a&gt; 协议下授权用户使用</translation>
    </message>
</context>
</TS>
